==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkBoostPrimMinimumSpanningTree.java <==
// java wrapper for vtkBoostPrimMinimumSpanningTree object
//

package vtk;
import vtk.*;

public class vtkBoostPrimMinimumSpanningTree extends vtkTreeAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetEdgeWeightArrayName_2(String id0);
  public void SetEdgeWeightArrayName(String id0)
    { SetEdgeWeightArrayName_2(id0); }

  private native void SetOriginVertex_3(int id0);
  public void SetOriginVertex(int id0)
    { SetOriginVertex_3(id0); }

  private native void SetCreateGraphVertexIdArray_4(boolean id0);
  public void SetCreateGraphVertexIdArray(boolean id0)
    { SetCreateGraphVertexIdArray_4(id0); }

  private native boolean GetCreateGraphVertexIdArray_5();
  public boolean GetCreateGraphVertexIdArray()
    { return GetCreateGraphVertexIdArray_5(); }

  private native void CreateGraphVertexIdArrayOn_6();
  public void CreateGraphVertexIdArrayOn()
    { CreateGraphVertexIdArrayOn_6(); }

  private native void CreateGraphVertexIdArrayOff_7();
  public void CreateGraphVertexIdArrayOff()
    { CreateGraphVertexIdArrayOff_7(); }

  private native void SetNegateEdgeWeights_8(boolean id0);
  public void SetNegateEdgeWeights(boolean id0)
    { SetNegateEdgeWeights_8(id0); }

  private native boolean GetNegateEdgeWeights_9();
  public boolean GetNegateEdgeWeights()
    { return GetNegateEdgeWeights_9(); }

  private native void NegateEdgeWeightsOn_10();
  public void NegateEdgeWeightsOn()
    { NegateEdgeWeightsOn_10(); }

  private native void NegateEdgeWeightsOff_11();
  public void NegateEdgeWeightsOff()
    { NegateEdgeWeightsOff_11(); }

  public vtkBoostPrimMinimumSpanningTree() { super(); }

  public vtkBoostPrimMinimumSpanningTree(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.1-2-aarch64.pkg.tar.xz: vtk/vtkBoostPrimMinimumSpanningTree.java <==
// java wrapper for vtkBoostPrimMinimumSpanningTree object
//

package vtk;
import vtk.*;

public class vtkBoostPrimMinimumSpanningTree extends vtkTreeAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetEdgeWeightArrayName_2(String id0);
  public void SetEdgeWeightArrayName(String id0)
    { SetEdgeWeightArrayName_2(id0); }

  private native void SetOriginVertex_3(int id0);
  public void SetOriginVertex(int id0)
    { SetOriginVertex_3(id0); }

  private native void SetCreateGraphVertexIdArray_4(boolean id0);
  public void SetCreateGraphVertexIdArray(boolean id0)
    { SetCreateGraphVertexIdArray_4(id0); }

  private native boolean GetCreateGraphVertexIdArray_5();
  public boolean GetCreateGraphVertexIdArray()
    { return GetCreateGraphVertexIdArray_5(); }

  private native void CreateGraphVertexIdArrayOn_6();
  public void CreateGraphVertexIdArrayOn()
    { CreateGraphVertexIdArrayOn_6(); }

  private native void CreateGraphVertexIdArrayOff_7();
  public void CreateGraphVertexIdArrayOff()
    { CreateGraphVertexIdArrayOff_7(); }

  private native void SetNegateEdgeWeights_8(boolean id0);
  public void SetNegateEdgeWeights(boolean id0)
    { SetNegateEdgeWeights_8(id0); }

  private native boolean GetNegateEdgeWeights_9();
  public boolean GetNegateEdgeWeights()
    { return GetNegateEdgeWeights_9(); }

  private native void NegateEdgeWeightsOn_10();
  public void NegateEdgeWeightsOn()
    { NegateEdgeWeightsOn_10(); }

  private native void NegateEdgeWeightsOff_11();
  public void NegateEdgeWeightsOff()
    { NegateEdgeWeightsOff_11(); }

  public vtkBoostPrimMinimumSpanningTree() { super(); }

  public vtkBoostPrimMinimumSpanningTree(long id) { super(id); }
  public native long   VTKInit();

}
